@@ -11,28 +11,26 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from __future__ import absolute_import, unicode_literals, print_function
 import collections
 import hashlib
 import io
 import os
 import subprocess
+from hashlib import blake2b
 
 import pkginfo
 import pkg_resources
 
-try:
-    from hashlib import blake2b
-except ImportError:
-    try:
-        from pyblake2 import blake2b
-    except ImportError:
-        blake2b = None
-
 from twine.wheel import Wheel
 from twine.wininst import WinInst
 from twine import exceptions
 
+try:
+    FileNotFoundError = FileNotFoundError
+except NameError:
+    FileNotFoundError = IOError  # Py2
+
+
 DIST_TYPES = {
     "bdist_wheel": Wheel,
     "bdist_wininst": WinInst,
@@ -50,7 +48,7 @@ DIST_EXTENSIONS = {
 }
 
 
-class PackageFile(object):
+class PackageFile:
     def __init__(self, filename, comment, metadata, python_version, filetype):
         self.filename = filename
         self.basefilename = os.path.basename(filename)
@@ -84,6 +82,15 @@ class PackageFile(object):
                 os.path.basename(filename)
             )
 
+        # If pkginfo encounters a metadata version it doesn't support, it may
+        # give us back empty metadata. At the very least, we should have a name
+        # and version
+        if not (meta.name and meta.version):
+            raise exceptions.InvalidDistribution(
+                "Invalid distribution metadata. Try upgrading twine if "
+                "possible."
+            )
+
         if dtype == "bdist_egg":
             pkgd = pkg_resources.Distribution.from_filename(filename)
             py_version = pkgd.py_version
@@ -160,20 +167,41 @@ class PackageFile(object):
             self.gpg_signature = (signature_filename, gpg.read())
 
     def sign(self, sign_with, identity):
-        print("Signing {}".format(self.basefilename))
+        print(f"Signing {self.basefilename}")
         gpg_args = (sign_with, "--detach-sign")
         if identity:
             gpg_args += ("--local-user", identity)
         gpg_args += ("-a", self.filename)
-        subprocess.check_call(gpg_args)
+        self.run_gpg(gpg_args)
 
         self.add_gpg_signature(self.signed_filename, self.signed_basefilename)
 
+    @classmethod
+    def run_gpg(cls, gpg_args):
+        try:
+            subprocess.check_call(gpg_args)
+            return
+        except FileNotFoundError:
+            if gpg_args[0] != "gpg":
+                raise exceptions.InvalidSigningExecutable(
+                    "{} executable not available.".format(gpg_args[0]))
+
+        print("gpg executable not available. Attempting fallback to gpg2.")
+        try:
+            subprocess.check_call(("gpg2",) + gpg_args[1:])
+        except FileNotFoundError:
+            print("gpg2 executable not available.")
+            raise exceptions.InvalidSigningExecutable(
+                "'gpg' or 'gpg2' executables not available. "
+                "Try installing one of these or specifying an executable "
+                "with the --sign-with flag."
+            )
+
 
 Hexdigest = collections.namedtuple('Hexdigest', ['md5', 'sha2', 'blake2'])
 
 
-class HashManager(object):
+class HashManager:
     """Manage our hashing objects for simplicity.
 
     This will also allow us to better test this logic.
