@@ -12,14 +12,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from __future__ import unicode_literals
-
 from twine import exceptions
 from twine import repository
 from twine import utils
 
 
-class Settings(object):
+class Settings:
     """Object that manages the configuration for Twine.
 
     This object can only be instantiated with keyword arguments.
